/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	GraphicsUtilites.h

	@description
		Utility file for graphics

	@author		Gordon Lee
*/

#ifndef GRAPHICSUTILITIES_H
#define GRAPHICSUTILITIES_H
#pragma once

// Includes
#include <d3d9.h>
#include <d3dx9.h>
#include <dxerr.h>
#pragma comment(lib, "dxerr.lib")
#include <string>

// Namespace
namespace Test
{
////////////////////////////////////////////////////////////////////////////////
// Error checking
#ifndef NOD3DERRORCHECKING
#define D3DHR(x)                                \
{                                               \
    HRESULT hr = x;                             \
	if(FAILED(hr))                              \
	{                                           \
		DXTrace(__FILE__,__LINE__,hr,#x,FALSE); \
	}                                           \
}
#else
#define D3DHR(x) x
#endif

#define SAFE_DELETE_ARRAY(p) { if(p) { delete[] (p); (p)=NULL; } }
#define SAFE_DELETE(p) { if(p) { delete (p); (p)=NULL; } }
#define SAFE_RELEASE(p) { if(p) { (p)->Release(); (p)=NULL; } }

struct D3DDeviceCaps
{
	D3DDeviceCaps()
		: m_pixelShader3_0Support(true),
		  m_vertexShader3_0Support(true),
		  m_capsFlags(NULL),
		  m_maxConstants(0),
		  m_maxRenderTargets(0)
	{ }

	bool m_pixelShader3_0Support;
	bool m_vertexShader3_0Support;
	DWORD m_capsFlags;
	unsigned m_maxConstants;
	unsigned m_maxRenderTargets;
};

struct sRenderPacketText
{
	LPD3DXFONT m_font;
	std::string m_text;
	RECT m_rect;
	D3DXCOLOR m_color;
	DWORD m_flags;
};
////////////////////////////////////////////////////////////////////////////////
}

#endif
