/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cApplication.h

	@description
		Class for Application that handles the window and run loop

	@author		Gordon Lee
*/

#ifndef C_APPLICATION_H
#define C_APPLICATION_H
#pragma once

// Includes
#define WIN32_LEAN_AND_MEAN
#undef UNICODE
#undef _UNICODE
#include <windows.h>
#include <string>
#include "cTimer.h"
#include "cChain.h"

// Namespace
namespace Test
{
////////////////////////////////////////////////////////////////////////////////
// Defines
#define SCREEN_WIDTH	1024
#define SCREEN_HEIGHT	768
#define BUF_LEN			256
#define FRAMERATE_CAP	17

class cApplication
{
public:
	static cApplication *	Instance(void);
	static cApplication *	Create(void);
	static void				Destroy(void);
	bool					Initialize(HINSTANCE _hInstance, std::string _title);

	bool					OpenConsoleWindow(void);
	bool					CloseConsoleWindow(void);

	void					Run(void);
	void					AppLoop(void);
	LRESULT					AppWndProc(HWND _hWnd, UINT _msg, WPARAM _wParam, LPARAM _lParam);

	cChain *				GetChain(void) { return m_chain; }
	void					SetChain(cChain *_chain) { m_chain = _chain; }

private:
							cApplication();
							~cApplication();

	// Data members
	std::string m_winClassName;
	HINSTANCE m_hInstance;
	HWND m_hWnd;
	bool m_bConsoleOpen;
	cTimer m_debugTimer;
	cTimer m_loopTimer;
	cChain *m_chain;
	float m_height;
	float m_radius;
	float m_theta;
};
////////////////////////////////////////////////////////////////////////////////
// Global define
#define g_pcApplication cApplication::Instance()
}

#endif
