/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cCamera.h

	@description
		Class for DirectX camera

	@author		Gordon Lee
*/

#ifndef C_CAMERA_H
#define C_CAMERA_H
#pragma once

// Includes
#include <d3d9.h>
#include <d3dx9.h>

namespace Test
{
////////////////////////////////////////////////////////////////////////////////
class cCamera
{
public:
	cCamera()
	: m_position(0.f, 0.f, 0.f), m_up(0.f, 0.f, 0.f), m_look(0.f, 0.f, 0.f),
		m_side(0.f, 0.f, 0.f), m_assumedUp(0.f, 1.f, 0.f)
	{
	}

	inline void Orthonormalize(void)
	{
		D3DXVec3Cross(&m_side, &m_look, &m_assumedUp);
		D3DXVec3Cross(&m_up, &m_side, &m_look);
	}

	inline D3DXMATRIX &GetView(void) { return m_view; }
	inline void BuildView(void)
	{
		D3DXVECTOR3 _look = m_position + m_look;
		D3DXMatrixLookAtLH(&m_view, &m_position, &_look, &m_up);
	}

	inline D3DXVECTOR3 GetPosition(void) { return m_position; }
	inline D3DXVECTOR3 GetUp(void) { return m_up; }
	inline D3DXVECTOR3 GetLook(void) { return m_look; }
	inline D3DXVECTOR3 GetSide(void) { return m_side; }

	inline void SetPosition(D3DXVECTOR3 _v) { m_position = _v; }
	inline void SetUp(D3DXVECTOR3 _v) { m_up = _v; }
	inline void SetLook(D3DXVECTOR3 _v) { m_look = _v; }
	inline void SetSide(D3DXVECTOR3 _v) { m_side = _v; }

private:
	D3DXVECTOR3 m_position;
	D3DXVECTOR3 m_up;
	D3DXVECTOR3 m_look;
	D3DXVECTOR3 m_side;

	D3DXVECTOR3 m_assumedUp;
	D3DXMATRIX m_view;
};
////////////////////////////////////////////////////////////////////////////////
}

#endif
