/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cChain.h

	@description
		Class for a chain of links solved by an IK solver

	@author		Gordon Lee
*/

#ifndef C_CHAIN_H
#define C_CHAIN_H
#pragma once

// Includes
#include <d3d9.h>
#include <d3dx9.h>
#include <utility>

// Defines
#define NULL 0
#define PI 3.14159265f
#define NUM_LINKS 2

// Namespace
namespace Test
{
////////////////////////////////////////////////////////////////////////////////
// Link struct
struct sLink
{
	float m_length;
	D3DXVECTOR3 *m_startPt;
	D3DXVECTOR3 *m_endPt;
	float m_yaw;
	float m_pitch;
	float m_roll;
};

class cChain
{
public:
				cChain(float _L1, float _L2);
				~cChain();

	void		Draw(void);
	
	void		Solve(void);

	// data members
	sLink m_links[NUM_LINKS];
	D3DXVECTOR3 m_pts[NUM_LINKS + 1];

	D3DXVECTOR3 m_target;
	LPD3DXMESH m_ptMesh;
	LPDIRECT3DDEVICE9 m_D3DDevice;
};
////////////////////////////////////////////////////////////////////////////////
}

#endif
