/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cFontManager.h

	@description
		Class for a font manager

	@author		Gordon Lee
*/

// Includes
#include "cFontManager.h"
#include "GraphicsUtilities.h"

namespace Test
{
////////////////////////////////////////////////////////////////////////////////
/**
	Constructor
*/
cFontManager::cFontManager()
: m_D3DDevice(NULL)
{
}

/**
	Deconstructor
*/
cFontManager::~cFontManager()
{
	FontMap::iterator _iter = m_fontMap.begin();
	FontMap::iterator _iend = m_fontMap.end();
	for (; _iter != _iend; ++_iter)
	{
		SAFE_RELEASE(_iter->second);
	}
	m_fontMap.clear();

	ClearTextStack();
}

/**
	Initialize

	@param LPDIRECT3DDEVICE9 _D3DDevice

	@return bool
*/
bool cFontManager::Initialize(LPDIRECT3DDEVICE9 _D3DDevice)
{
	m_D3DDevice = _D3DDevice;

	CreateNewFont("Arial", 18, FW_BOLD);

	return true;
}

/**
	Create New Font

	@param std::string _fontName
	@param unsigned _size
	@param unsigned _weight

	@return LPD3DXFONT
*/
LPD3DXFONT cFontManager::CreateNewFont(std::string _fontName, unsigned _size, unsigned _weight)
{
	LPD3DXFONT _font;
	D3DHR(D3DXCreateFont(m_D3DDevice, _size, 0, _weight, 0, FALSE, DEFAULT_CHARSET, OUT_DEFAULT_PRECIS, DEFAULT_QUALITY,
						 DEFAULT_PITCH | FF_DONTCARE, TEXT(_fontName.c_str()), &_font));
	m_fontMap.insert(FontMap::value_type(_fontName, _font));
	return _font;
}

/**
	Get Font

	@param std::string_fontName

	@return LPD3DXFONT
*/
LPD3DXFONT cFontManager::GetFont(std::string _fontName)
{
	FontMap::iterator _iter = m_fontMap.find(_fontName);
	if (_iter != m_fontMap.end())
	{
		return _iter->second;
	}
	return NULL;
}

/**
	Push Text Packet

	@param sRenderPacketText *_textPacket
*/
void cFontManager::PushTextPacket(sRenderPacketText *_textPacket)
{
	D3DHR(_textPacket->m_font->DrawText(NULL, _textPacket->m_text.c_str(), -1, &_textPacket->m_rect, _textPacket->m_flags | DT_CALCRECT, _textPacket->m_color));
	m_textStack.push(_textPacket);
}

/**
	Clear Text Stack
*/
void cFontManager::ClearTextStack(void)
{
	while (!m_textStack.empty())
	{
		delete m_textStack.top();
		m_textStack.pop();
	}
}
////////////////////////////////////////////////////////////////////////////////
}
