/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cGraphics.h

	@description
		Class for a graphics engine using DirectX

	@author		Gordon Lee
*/

#ifndef C_GRAPHICS_H
#define C_GRAPHICS_H
#pragma once

// Includes
#include <d3d9.h>
#include <d3dx9.h>
#include <string>

// Namespace
namespace Test
{
// Forward declarations
class cCamera;
class cGraphicsRenderer;
class cFontManager;
class cChain;

////////////////////////////////////////////////////////////////////////////////
class cGraphics
{
public:
	static cGraphics *	Instance(void);
	static cGraphics *	Create(void);
	static void			Destroy(void);
	bool				Initialize(HWND _hWnd);

	void				Update(void);
	LPDIRECT3DDEVICE9	GetDevice(void);
	void				DrawLine(D3DXVECTOR3 _p0, D3DXVECTOR3 _p1, D3DXCOLOR _color);
	void				DisplayText(unsigned _width, unsigned _height, std::string _text, std::string _fontName, D3DXCOLOR _color, DWORD _flags);
	cCamera *			GetCamera(void) { return m_camera; }
	void				SetChain(cChain *_chain) { m_chain = _chain; }

private:
						cGraphics();
						~cGraphics();

	void				BeginRendering(D3DCOLOR _color);
	void				EndRendering(void);
	void				RenderText(void);
	void				SetupCamera(void);
	void				DrawOrigin(void);

	// Data members
	cCamera *m_camera;
	cGraphicsRenderer * m_renderer;
	cFontManager *m_fontManager;
	cChain *m_chain;
};
////////////////////////////////////////////////////////////////////////////////
#define g_pcGraphics cGraphics::Instance()
}

#endif
