/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cGraphicsRenderer.h

	@description
		Class for the rendering of the graphics engine

	@author		Gordon Lee
*/

#ifndef C_GRAPHICSRENDERER_H
#define C_GRAPHICSRENDERER_H
#pragma once

// Includes
#include <d3d9.h>
#include <d3dx9.h>
#include "GraphicsUtilities.h"
#include "cChain.h"

// Namespace
namespace Test
{
////////////////////////////////////////////////////////////////////////////////
class cGraphicsRenderer
{
public:
						cGraphicsRenderer();
						~cGraphicsRenderer();

	bool				Initialize(HWND _hWnd);

	void				CheckDeviceCaps(void);

	bool				IsDeviceLost(void);
	LPDIRECT3DDEVICE9	GetDevice(void) { return m_D3DDevice; }

	void				BuildProjection(void);
	D3DXMATRIX&			GetProjection(void) { return m_proj; }
	void				SetView(D3DXMATRIX _view) { m_view = _view; }
	D3DXMATRIX&			GetView(void) { return m_view; }

	void				BeginRendering(D3DCOLOR _color);
	void				EndRendering(void);
	
	void				RenderLine(D3DXVECTOR3 _p0, D3DXVECTOR3 _p1, D3DXCOLOR _color);
	void				RenderText(sRenderPacketText *_packet);

private:
	// Data members
	LPDIRECT3D9 m_D3DObject;
	LPDIRECT3DDEVICE9 m_D3DDevice;
	D3DPRESENT_PARAMETERS m_D3DPP;
	D3DDeviceCaps m_D3DDeviceCaps;

	LPDIRECT3DVERTEXBUFFER9 m_vertexBuffer;
	LPDIRECT3DINDEXBUFFER9 m_indexBuffer;

	D3DXMATRIX m_proj;
	D3DXMATRIX m_view;

	LPD3DXLINE m_D3DLine;
};
////////////////////////////////////////////////////////////////////////////////
}

#endif
