/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cInput.cpp

	@description
		Class for keyboard input

	@author		Gordon Lee
*/

// Includes
#include "cInput.h"
#include <string.h>

// Namespace
namespace Test
{
////////////////////////////////////////////////////////////////////////////////
/**
	Constructor
*/
cInput::cInput()
{
}

/**
	Deconstructor
*/
cInput::~cInput()
{
}

/**
	Instance
	
	@return cInput *
*/
cInput *cInput::Instance(void)
{
	static cInput *s_input = new cInput();
	return s_input;
}

/**
	Create

	@return cInput *
*/
cInput *cInput::Create(void)
{
	return Instance();
}

/**
	Destroy
*/
void cInput::Destroy(void)
{
	delete Instance();
}

/**
	Initialize

	@return bool
*/
bool cInput::Initialize(void)
{
	memset(m_keyState, (unsigned char)false, NUM_KEYS * sizeof(unsigned char));
	memset(m_prevKeyState, (unsigned char)false, NUM_KEYS * sizeof(unsigned char));

	return true;
}

/**
	Update called from universal update
*/
void cInput::Update(void)
{
	// Save previous key state
	memcpy(m_prevKeyState, m_keyState, NUM_KEYS * sizeof(unsigned char));
}

/**
	Update key down

	@param const unsigned _wp
*/
void cInput::ProcessKeyDown(const unsigned _wp)
{
	m_prevKeyState[_wp] = m_keyState[_wp];
	m_keyState[_wp] = (unsigned char)true;
}

/**
	Update key up

	@param const unsigned _wp
*/
void cInput::ProcessKeyUp(const unsigned _wp)
{
	m_prevKeyState[_wp] = m_keyState[_wp];
	m_keyState[_wp] = (unsigned char)false;
}

/**
	Gets key press

	@param const unsigned _wp

	@return bool
*/
bool cInput::KeyPress(const unsigned _wp) const
{
	if (m_keyState[_wp] && !m_prevKeyState[_wp])
		return true;
	else
		return false;
}

/**
	Gets key down

	@param const unsigned _wp

	@return bool
*/
bool cInput::KeyDown(const unsigned _wp) const
{
	if (m_keyState[_wp])
		return true;
	else
		return false;
}

/**
	Gets key release

	@param const unsigned _wp

	@return bool
*/
bool cInput::KeyRelease(const unsigned _wp) const
{
	if (!m_keyState[_wp] && m_prevKeyState[_wp])
		return true;
	else
		return false;
}

/**
	Gets key up

	@param const unsigned _wp

	@return bool
*/
bool cInput::KeyUp(const unsigned _wp) const
{
	if (!m_keyState[_wp])
		return true;
	else
		return false;
}
////////////////////////////////////////////////////////////////////////////////
}
