/*
	Engineering Test: Links Configuration
	Gordon Lee

*******************************************************************************

	@filename	cTimer.cpp

	@description
		Class for a millisecond timer

	@author		Gordon Lee
*/

// Includes
#include "cTimer.h"
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#pragma warning(disable : 4201)	// Disable warnings regarding nameless struct
#include <mmsystem.h>
#pragma comment(lib, "winmm.lib")

// Namespace
namespace Test
{
////////////////////////////////////////////////////////////////////////////////
/**
	Constructor
*/
cTimer::cTimer()
: m_startTime(0), m_pausedTime(0), m_bStarted(false), m_bPaused(false)
{
}

/**
	Deconstructor
*/
cTimer::~cTimer()
{
}

/**
	Start Timer
*/
void cTimer::Start(void)
{
	m_bStarted = true;
	m_bPaused = false;

	m_startTime = timeGetTime();
}

/**
	Stop Timer
*/
void cTimer::Stop(void)
{
	m_bStarted = false;
	m_bPaused = false;
}

/**
	Pause Timer
*/
void cTimer::Pause(void)
{
	if (m_bStarted == true && m_bPaused == false)
	{
		m_bPaused = true;
		m_pausedTime = timeGetTime() - m_startTime;
	}
}

/**
	Unpause Timer
*/
void cTimer::Unpause(void)
{
	if (m_bPaused == true)
	{
		m_bPaused = false;
		m_startTime = timeGetTime() - m_pausedTime;
		m_pausedTime = 0;
	}
}

/**
	Get Time

	@return unsigned long
*/
unsigned long cTimer::GetTime(void)
{
	if (m_bStarted == true)
	{
		if(m_bPaused == true)
			return m_pausedTime;
		else
			return timeGetTime() - m_startTime;
	}

	return 0;
}

/**
	Is Started

	@return bool
*/
bool cTimer::IsStarted(void)
{
	return m_bStarted;
}

/**
	Is Paused

	@return bool
*/
bool cTimer::IsPaused(void)
{
	return m_bPaused;
}
////////////////////////////////////////////////////////////////////////////////
}
